import React, { useRef } from 'react'
import moment from 'moment';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import BanjiSearch from '@/components/BanjiSearch';
import { getInvoiceDetailList } from '@/services/invoiceDetail'
import { getExport } from '@/services/invoiceFill'

export default (props) => {
  const actionRef = useRef();

  const columns = [
    {
      title: '班次名称',
      dataIndex: 'invoiceId',
      key: 'invoiceId',
      search: true,
      hideInTable: true,
      renderFormItem: () => (
        <BanjiSearch placeholder='请输入班次名称' />
      ),
      formItemProps: {
        rules: [
          {
            required: true,
            message: '请输入班次名称',
          }
        ],
      }
    },
    {
      title: '姓名',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
    },
    {
      title: '开票单位',
      dataIndex: 'orgName',
      key: 'orgName',
      search: true,
    },
    {
      title: '纳税识别号',
      dataIndex: 'taxNo',
      key: 'taxNo',
      search: false,
    },
    {
      title: '地址',
      dataIndex: 'address',
      key: 'address',
      search: false,
    },
    {
      title: '电话',
      dataIndex: 'phone',
      key: 'phone',
      search: false,
    },
    {
      title: '开户银行',
      dataIndex: 'bankName',
      key: 'bankName',
      search: false,
    },
    {
      title: '开户行账号',
      dataIndex: 'cardNo',
      key: 'cardNo',
      search: false,
    },
    {
      title: '报销项目',
      dataIndex: 'itemName',
      key: 'itemName',
      search: false,
    },
    {
      title: '开票金额',
      dataIndex: 'charge',
      key: 'charge',
      search: false,
    },
    {
      title: '是否合开',
      dataIndex: 'mergeRemark',
      key: 'mergeRemark',
      search: false,
    },
    {
      title: '收件人姓名',
      dataIndex: 'mailUser',
      key: 'mailUser',
      search: false,
    },
    {
      title: '收件人电话',
      dataIndex: 'mailPhone',
      key: 'mailPhone',
      search: false,
    },
    {
      title: '外网电子邮箱',
      dataIndex: 'email',
      key: 'email',
      search: false,
    },
    {
      title: '收件人地址',
      dataIndex: 'mailAddress',
      key: 'mailAddress',
      search: false,
    },
    {
      title: '房号',
      dataIndex: 'roomCode',
      key: 'roomCode',
      search: false,
    },
    {
      title: '是否需要住宿清单',
      dataIndex: 'isNeedLodging',
      key: 'isNeedLodging',
      valueType: 'select',
      valueEnum: {
        0: '不需要',
        1: '需要'
      },
      search: false,
    },
    {
      title: '提交时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => t ? moment(t).format('YYYY-MM-DD HH:mm') : '-',
      width: 200,
      search: false
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        columns={columns}
        request={getInvoiceDetailList}
        expfunc={getExport}
        options={false}
        actionRef={actionRef}
        search={{
          defaultCollapsed: false
        }}
        form={{ ignoreRules: false }}
        manualRequest={true}
        revalidateOnFocus={false}
        rowKey="detailId"
        scroll={{ x: 2500 }}
      />
    </PageHeaderWrapper>
  )
}
